@@ -40,6 +40,14 @@ async def text_to_speech(request: TTSRequest, api_key: Optional[str] = None):
 
 
 if __name__ == '__main__':
+    data = {
+        "model": "CosyVoice2",
+        "input": "根据 prompt audio url克隆音色",
+        "prompt_wav_url": "https://s3.ffire.cc/files/jay_prompt.wav",
+        "response_format": "url"
+    }
+    print(TTSRequest(**data))
+
     request = TTSRequest(
         model="CosyVoice2",
         input="你好呀",
@@ -47,5 +55,6 @@ if __name__ == '__main__':
         response_format="b64_json"
     )
 
-    arun(text_to_speech(request))
+
+    # arun(text_to_speech(request))
     # print(MODELS.values())
