@@ -77,6 +77,8 @@ async def billing_for_tokens(
         api_key: Optional[str] = None,
 
         n: Optional[float] = None,  # 按次走以前逻辑也行
+
+        task_id: Optional[str] = None,
 ):
     """
 
@@ -99,12 +101,13 @@ async def billing_for_tokens(
     usage = usage or {}
     n = n and int(np.round(n))
 
-    client = AsyncOpenAI(api_key=api_key)
+    client = AsyncOpenAI(api_key=api_key, timeout=30)
     if n:
         _ = await client.images.generate(
             model=model,
             prompt="ChatfireAPI",
-            n=n
+            n=n,
+            user=task_id
         )
 
     elif "input_tokens" in usage:
@@ -112,14 +115,17 @@ async def billing_for_tokens(
             model=model,
             prompt="ChatfireAPI",
             n=n,
-            extra_body={"extra_fields": usage}
+            extra_body={"extra_fields": usage},
+
+            user=task_id
         )
     else:
         # todo 设计 id chatcmpl-NEdenEpvzGiKR2FfK2GmzK => 表达某些含义
         _ = await client.chat.completions.create(
             model=model,
             messages=[{"role": "user", "content": "ChatfireAPI"}],
-            extra_body={"extra_body": usage}
+            extra_body={"extra_body": usage},
+            user=task_id
         )
     return _
 
@@ -231,7 +237,8 @@ if __name__ == '__main__':
     usage = {
         "prompt_tokens": 1000, "completion_tokens": 100,  # "total_tokens": 2000,
     }
-    arun(billing_for_tokens(model="tokens", usage=usage))
+    arun(billing_for_tokens(model="tokens", usage=usage, task_id='xx'))
+    arun(billing_for_tokens(model="fal", usage=usage, task_id='xx'))
 
     # arun(create_usage_for_async_task(task_id="task_id", n=1))
 
@@ -274,12 +281,12 @@ if __name__ == '__main__':
     #   "progress": 99
     # }
 
-    data = {
-        "model": "veo3",
-        "prompt": "女人飞上天了",
-        "images": [
-            "https://oss.ffire.cc/files/kling_watermark.png"
-        ],
-        "enhance_prompt": True
-    }
+    # data = {
+    #     "model": "veo3",
+    #     "prompt": "女人飞上天了",
+    #     "images": [
+    #         "https://oss.ffire.cc/files/kling_watermark.png"
+    #     ],
+    #     "enhance_prompt": True
+    # }
     # print(get_billing_model(data, default_resolution=""))
